# mypy-boto3-codecommit

[![PyPI - mypy-boto3-codecommit](https://img.shields.io/pypi/v/mypy-boto3-codecommit.svg?color=blue)](https://pypi.org/project/mypy-boto3-codecommit)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-codecommit.svg?color=blue)](https://pypi.org/project/mypy-boto3-codecommit)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.CodeCommit 1.14.55](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codecommit.html#CodeCommit) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 3.0.4](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-codecommit](#mypy-boto3-codecommit)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `CodeCommit` service.

```bash
python -m pip install boto3-stubs[codecommit]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[codecommit]` in your environment: `python -m pip install 'boto3-stubs[codecommit]'`

Both type checking and auto-complete should work for `CodeCommit` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[codecommit]` in your environment: `python -m pip install 'boto3-stubs[codecommit]'`

Both type checking and auto-complete should work for `CodeCommit` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[codecommit]` in your environment: `python -m pip install 'boto3-stubs[codecommit]'`
- Run `mypy` as usual

Type checking should work for `CodeCommit` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[codecommit]` in your environment: `python -m pip install 'boto3-stubs[codecommit]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `CodeCommit` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`CodeCommitClient` provides annotations for `boto3.client("codecommit")`.

```python
import boto3

from mypy_boto3_codecommit import CodeCommitClient

client: CodeCommitClient = boto3.client("codecommit")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: CodeCommitClient = session.client("codecommit")
```

### Paginators annotations

`mypy_boto3_codecommit.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_codecommit import CodeCommitClient
from mypy_boto3_codecommit.paginator import (
    DescribePullRequestEventsPaginator,
    GetCommentsForComparedCommitPaginator,
    GetCommentsForPullRequestPaginator,
    GetDifferencesPaginator,
    ListBranchesPaginator,
    ListPullRequestsPaginator,
    ListRepositoriesPaginator,
)

client: CodeCommitClient = boto3.client("codecommit")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_pull_request_events_paginator: DescribePullRequestEventsPaginator = client.get_paginator("describe_pull_request_events")
get_comments_for_compared_commit_paginator: GetCommentsForComparedCommitPaginator = client.get_paginator("get_comments_for_compared_commit")
get_comments_for_pull_request_paginator: GetCommentsForPullRequestPaginator = client.get_paginator("get_comments_for_pull_request")
get_differences_paginator: GetDifferencesPaginator = client.get_paginator("get_differences")
list_branches_paginator: ListBranchesPaginator = client.get_paginator("list_branches")
list_pull_requests_paginator: ListPullRequestsPaginator = client.get_paginator("list_pull_requests")
list_repositories_paginator: ListRepositoriesPaginator = client.get_paginator("list_repositories")
```







### Typed dictionations

`mypy_boto3_codecommit.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_codecommit.type_defs import (
    ApprovalRuleEventMetadataTypeDef,
    ApprovalRuleOverriddenEventMetadataTypeDef,
    ApprovalRuleTemplateTypeDef,
    ApprovalRuleTypeDef,
    ApprovalStateChangedEventMetadataTypeDef,
    ApprovalTypeDef,
    BatchAssociateApprovalRuleTemplateWithRepositoriesErrorTypeDef,
    BatchAssociateApprovalRuleTemplateWithRepositoriesOutputTypeDef,
    BatchDescribeMergeConflictsErrorTypeDef,
    BatchDescribeMergeConflictsOutputTypeDef,
    BatchDisassociateApprovalRuleTemplateFromRepositoriesErrorTypeDef,
    BatchDisassociateApprovalRuleTemplateFromRepositoriesOutputTypeDef,
    BatchGetCommitsErrorTypeDef,
    BatchGetCommitsOutputTypeDef,
    BatchGetRepositoriesOutputTypeDef,
    BlobMetadataTypeDef,
    BranchInfoTypeDef,
    CommentsForComparedCommitTypeDef,
    CommentsForPullRequestTypeDef,
    CommentTypeDef,
    CommitTypeDef,
    ConflictMetadataTypeDef,
    ConflictResolutionTypeDef,
    ConflictTypeDef,
    CreateApprovalRuleTemplateOutputTypeDef,
    CreateCommitOutputTypeDef,
    CreatePullRequestApprovalRuleOutputTypeDef,
    CreatePullRequestOutputTypeDef,
    CreateRepositoryOutputTypeDef,
    CreateUnreferencedMergeCommitOutputTypeDef,
    DeleteApprovalRuleTemplateOutputTypeDef,
    DeleteBranchOutputTypeDef,
    DeleteCommentContentOutputTypeDef,
    DeleteFileEntryTypeDef,
    DeleteFileOutputTypeDef,
    DeletePullRequestApprovalRuleOutputTypeDef,
    DeleteRepositoryOutputTypeDef,
    DescribeMergeConflictsOutputTypeDef,
    DescribePullRequestEventsOutputTypeDef,
    DifferenceTypeDef,
    EvaluatePullRequestApprovalRulesOutputTypeDef,
    EvaluationTypeDef,
    FileMetadataTypeDef,
    FileModesTypeDef,
    FileSizesTypeDef,
    FileTypeDef,
    FolderTypeDef,
    GetApprovalRuleTemplateOutputTypeDef,
    GetBlobOutputTypeDef,
    GetBranchOutputTypeDef,
    GetCommentOutputTypeDef,
    GetCommentReactionsOutputTypeDef,
    GetCommentsForComparedCommitOutputTypeDef,
    GetCommentsForPullRequestOutputTypeDef,
    GetCommitOutputTypeDef,
    GetDifferencesOutputTypeDef,
    GetFileOutputTypeDef,
    GetFolderOutputTypeDef,
    GetMergeCommitOutputTypeDef,
    GetMergeConflictsOutputTypeDef,
    GetMergeOptionsOutputTypeDef,
    GetPullRequestApprovalStatesOutputTypeDef,
    GetPullRequestOutputTypeDef,
    GetPullRequestOverrideStateOutputTypeDef,
    GetRepositoryOutputTypeDef,
    GetRepositoryTriggersOutputTypeDef,
    IsBinaryFileTypeDef,
    ListApprovalRuleTemplatesOutputTypeDef,
    ListAssociatedApprovalRuleTemplatesForRepositoryOutputTypeDef,
    ListBranchesOutputTypeDef,
    ListPullRequestsOutputTypeDef,
    ListRepositoriesForApprovalRuleTemplateOutputTypeDef,
    ListRepositoriesOutputTypeDef,
    ListTagsForResourceOutputTypeDef,
    LocationTypeDef,
    MergeBranchesByFastForwardOutputTypeDef,
    MergeBranchesBySquashOutputTypeDef,
    MergeBranchesByThreeWayOutputTypeDef,
    MergeHunkDetailTypeDef,
    MergeHunkTypeDef,
    MergeMetadataTypeDef,
    MergeOperationsTypeDef,
    MergePullRequestByFastForwardOutputTypeDef,
    MergePullRequestBySquashOutputTypeDef,
    MergePullRequestByThreeWayOutputTypeDef,
    ObjectTypesTypeDef,
    OriginApprovalRuleTemplateTypeDef,
    PaginatorConfigTypeDef,
    PostCommentForComparedCommitOutputTypeDef,
    PostCommentForPullRequestOutputTypeDef,
    PostCommentReplyOutputTypeDef,
    PullRequestCreatedEventMetadataTypeDef,
    PullRequestEventTypeDef,
    PullRequestMergedStateChangedEventMetadataTypeDef,
    PullRequestSourceReferenceUpdatedEventMetadataTypeDef,
    PullRequestStatusChangedEventMetadataTypeDef,
    PullRequestTargetTypeDef,
    PullRequestTypeDef,
    PutFileEntryTypeDef,
    PutFileOutputTypeDef,
    PutRepositoryTriggersOutputTypeDef,
    ReactionForCommentTypeDef,
    ReactionValueFormatsTypeDef,
    ReplaceContentEntryTypeDef,
    RepositoryMetadataTypeDef,
    RepositoryNameIdPairTypeDef,
    RepositoryTriggerExecutionFailureTypeDef,
    RepositoryTriggerTypeDef,
    SetFileModeEntryTypeDef,
    SourceFileSpecifierTypeDef,
    SubModuleTypeDef,
    SymbolicLinkTypeDef,
    TargetTypeDef,
    TestRepositoryTriggersOutputTypeDef,
    UpdateApprovalRuleTemplateContentOutputTypeDef,
    UpdateApprovalRuleTemplateDescriptionOutputTypeDef,
    UpdateApprovalRuleTemplateNameOutputTypeDef,
    UpdateCommentOutputTypeDef,
    UpdatePullRequestApprovalRuleContentOutputTypeDef,
    UpdatePullRequestDescriptionOutputTypeDef,
    UpdatePullRequestStatusOutputTypeDef,
    UpdatePullRequestTitleOutputTypeDef,
    UserInfoTypeDef,
)

def get_structure() -> ApprovalRuleEventMetadataTypeDef:
    return {
      ...
    }
```
